@@ -273,7 +273,7 @@ FrameCFrChanFree( FrameCError** Error,
 void
 FrameCFrChanQuery(  FrameCError** Error,
 		    const fr_chan_t* Channel,
-		    fr_chan_fields Option,
+		    int Option,
 		    ... )
 {
   using FrameCPP::FrAdcData;
@@ -642,7 +642,7 @@ FrameCFrChanRead( FrameCError** Error,
 void
 FrameCFrChanSet(  FrameCError** Error,
 		  const fr_chan_t* Channel,
-		  fr_chan_fields Option,
+		  int Option,
 		  ... )
 {
   using FrameCPP::FrAdcData;
@@ -1118,7 +1118,7 @@ FrameCFrChanVectorExpand( FrameCError** Error,
 void
 FrameCFrChanVectorQuery(  FrameCError** Error,
 			  const fr_chan_t* Channel,
-			  fr_vect_fields Option,
+			  int Option,
 			  ... )
 {
   Set( Error );
@@ -1479,7 +1479,7 @@ FrameCFrChanVectorQuery(  FrameCError** Error,
 void
 FrameCFrChanVectorSet(  FrameCError** Error,
 			fr_chan_t* Channel,
-			fr_vect_fields Option,
+			int Option,
 			... )
 {
   using FrameCPP::FrVect;
@@ -1493,7 +1493,7 @@ FrameCFrChanVectorSet(  FrameCError** Error,
     va_list	ap;
     va_start( ap, Option );
 
-    fr_vect_fields	opt = Option;
+    fr_vect_fields	opt = fr_vect_fields( Option );
 
     if ( oochannel )
     {
