@@ -260,7 +260,7 @@ namespace FrameC
 void
 FrameCFrDetectorQuery( FrameCError** Error,
 		       const fr_detector_t* Detector,
-		       fr_detector_fields Option,
+		       int Option,
 		       ... )
 {
   using namespace FrameC;
@@ -563,8 +563,12 @@ FrameCFrDetectorQuery( FrameCError** Error,
 	/**
 	 * </ul>
 	 */
+#if 0
 	int next_opt = va_arg(ap, int /* fr_frame_fields*/ );
 	Option = (fr_detector_fields)next_opt;
+#else
+	Option = va_arg(ap, int /* fr_frame_fields*/ );
+#endif
       }
     }
     else
