@@ -134,8 +134,8 @@ FrameCFrTOCFree( FrameCError** Error,
 void
 FrameCFrTOCQuery(  FrameCError** Error,
 		   const fr_toc_t* TOC,
-	     fr_toc_fields Option,
-	     ... )
+		   int Option,
+		   ... )
 {
   Set( Error );
 
@@ -742,8 +742,12 @@ FrameCFrTOCQuery(  FrameCError** Error,
 	/**
 	 * </ul>
 	 */
+#if 0
 	int next_opt = va_arg(ap, int /* fr_vect_fields*/ );
 	Option = (fr_toc_fields)next_opt;
+#else /* 0 */
+	Option = va_arg(ap, int /* fr_vect_fields*/ );
+#endif /* 0 */
       }
     }
     else
