@@ -265,7 +265,7 @@ FrameCFrameHFrHistoryAdd(  FrameCError** Error,
 void
 FrameCFrameHQuery( FrameCError** Error,
 		   const frame_h_t* Frame,
-		   frame_h_fields Option,
+		   int Option,
 		   ... )
 {
   using namespace FrameC;
@@ -450,8 +450,12 @@ FrameCFrameHQuery( FrameCError** Error,
 	/**
 	 * </ul>
 	 */
+#if 0
 	int next_opt = va_arg(ap, int /* frame_h_fields*/ );
 	Option = (frame_h_fields)next_opt;
+#else
+	Option = va_arg(ap, int /* frame_h_fields*/ );
+#endif
       }
     }
     else
@@ -483,7 +487,7 @@ FrameCFrameHQuery( FrameCError** Error,
 void
 FrameCFrameHSet( FrameCError** Error,
 		 const frame_h_t* Frame,
-		 frame_h_fields Option,
+		 int Option,
 		 ... )
 {
   using namespace FrameC;
@@ -547,8 +551,12 @@ FrameCFrameHSet( FrameCError** Error,
 	/**
 	 * </ul>
 	 */
+#if 0
 	int next_opt = va_arg(ap, int /* frame_h_fields*/ );
 	Option = (frame_h_fields)next_opt;
+#else
+	Option = va_arg(ap, int /* frame_h_fields*/ );
+#endif /* 0 */
       }
     }
     else
