@@ -420,11 +420,13 @@ namespace FrameCPP
 		      Level, CompressionMapping,
 		      data_out, data_out_len );
 	break;
+BEGIN_WIMPLICIT_FALLTHROUGH
       case MODE_ZERO_SUPPRESS_2_OTHERWISE_GZIP:
       case MODE_ZERO_SUPPRESS_2_4_OTHERWISE_GZIP:
       case MODE_ZERO_SUPPRESS_2_4_8_OTHERWISE_GZIP:
 	gzip_others = true;
 	// :TRICKY: Fall through
+END_WIMPLICIT_FALLTHROUGH
       case MODE_ZERO_SUPPRESS_WORD_8:
       case MODE_ZERO_SUPPRESS_WORD_4:
       case MODE_ZERO_SUPPRESS_INT_FLOAT:
@@ -440,9 +442,11 @@ namespace FrameCPP
 	    compress_complex = true;
 	    word_size = 8;
 	    break;
+BEGIN_WIMPLICIT_FALLTHROUGH
 	  case MODE_ZERO_SUPPRESS_WORD_4:
 	    compress_complex = true;
 	    // :TRICKY: Fall through
+END_WIMPLICIT_FALLTHROUGH
 	  case MODE_ZERO_SUPPRESS_2_4_OTHERWISE_GZIP:
 	  case MODE_ZERO_SUPPRESS_INT_FLOAT:
 	    word_size = 4;
@@ -773,6 +777,7 @@ namespace FrameCPP
 					 data_out_len );
 	}
 	break;
+BEGIN_WIMPLICIT_FALLTHROUGH
       case MODE_ZERO_SUPPRESS_WORD_4:
 	if ( dt == FR_VECT_8C )
 	{
@@ -786,6 +791,8 @@ namespace FrameCPP
 					       data_out_len );
 	  break;
 	}
+	// :TRICKY: Fall through
+END_WIMPLICIT_FALLTHROUGH
       case MODE_ZERO_SUPPRESS_INT_FLOAT:
 	{
 	  AT( );
