@@ -731,6 +731,14 @@ namespace FrameCPP
 							 false );
     }
 
+    IFrameStream::object_type IFrameStream::
+    readFrEvent( const std::string& EventType, fr_event_offset_type Index )
+    {
+      return
+	read_indexed_fr_struct< FrameSpec::Info::FSI_FR_EVENT >( EventType, Index,
+								 true );
+    }
+
     IFrameStream::object_type IFrameStream::
     readFrProcData( INT_4U Frame, const std::string& Channel )
     {
@@ -803,6 +811,14 @@ namespace FrameCPP
 							     false );
     }
 
+    IFrameStream::object_type IFrameStream::
+    readFrSimEvent( const std::string& EventType, fr_event_offset_type Index )
+    {
+      return
+	read_indexed_fr_struct< FrameSpec::Info::FSI_FR_SIM_EVENT >( EventType, Index,
+								     true );
+    }
+
     IFrameStream::object_type IFrameStream::
     readNextFrame( )
     try
@@ -1439,6 +1455,22 @@ namespace FrameCPP
       return TOC->positionSimEvent( Frame, Channel );
     }
 
+    template< >
+    INT_8U IFrameStream::position_index< FrameSpec::Info::FSI_FR_EVENT,
+					 std::string >
+    ( const FrTOC* TOC, const std::string& Channel, INT_4U Index ) const
+    {
+      return TOC->positionEvent( Channel, Index );
+    }
+
+    template< >
+    INT_8U IFrameStream::position_index< FrameSpec::Info::FSI_FR_SIM_EVENT,
+					 std::string >
+    ( const FrTOC* TOC, const std::string& Channel, INT_4U Index ) const
+    {
+      return TOC->positionSimEvent( Channel, Index );
+    }
+
     template< INT_4U ClassType, typename ChannelType >
     IFrameStream::object_type IFrameStream::
     advance_to_fr_struct( INT_4U Frame, ChannelType Channel )
@@ -1532,6 +1564,99 @@ namespace FrameCPP
       return retval;
     }
 
+    template< INT_4U ClassType, typename ChannelType >
+    IFrameStream::object_type IFrameStream::
+    advance_to_indexed_fr_struct( ChannelType Channel, INT_4U Index )
+    {
+      object_type	retval;
+      const FrTOC*	toc(  dynamic_cast< const FrTOC* >( GetTOC( ) ) );
+
+      //-----------------------------------------------------------------
+      // Position within the file where the frame starts
+      //-----------------------------------------------------------------
+      if ( toc )
+      {
+	//---------------------------------------------------------------
+	// Fast seek implementation via table of contents.
+	//---------------------------------------------------------------
+	const std::streampos offset
+	  = position_index< ClassType >( toc, Channel, Index );
+	if ( offset == (std::streampos)0 )
+	{
+	  std::ostringstream	msg;
+
+	  msg << "channel: " << Channel
+	      << " does not exist at index: " << Index
+	    ;
+	  throw std::range_error( msg.str( ) );
+	}
+
+	clear( );
+	seekg( offset, std::ios::beg );
+	retval = Read( );
+	while ( good( )
+		&& retval.get( )
+		&& ( ( retval->GetClass( ) == FrameSpec::Info::FSI_FR_SE )
+		     || ( retval->GetClass( ) == FrameSpec::Info::FSI_FR_SH ) ) )
+	{
+	  //-------------------------------------------------------------
+	  // Ignore structure definition components
+	  //-------------------------------------------------------------
+	  retval = Read( );
+	}
+	if ( !good( ) )
+	{
+	  std::ostringstream	msg;
+	  msg << "After reading object of type: "
+	      << frameSpecInfo( ).FrameObject( FrameSpec::Info::frame_object_types( ClassType ) )->ObjectStructName( )
+	      << " stream is no longer in good state."
+	      << " ( ChannelType: " << Channel
+	      << " Index: " << Index
+	      << " file position offset: " << offset
+	      << ")"
+	    ;
+	  throw
+	    std::runtime_error ( msg.str( ) );
+	}
+	if ( ( ! retval )
+	     || ( retval->GetClass( ) != ClassType ) )
+	{
+	  std::ostringstream	msg;
+
+	  msg << "The object named: " << Channel << " at location " << offset
+	      << " is not a "
+	      << frameSpecInfo( ).FrameObject( FrameSpec::Info::frame_object_types( ClassType ) )->ObjectStructName( )
+	      << " structure."
+	    ;
+	  if ( retval.get( ) )
+	  {
+	    msg << " It is instead of type: " << retval->ObjectStructName( );
+	  }
+	  else
+	  {
+	    msg << " It is instead of type: NULL";
+	  }
+	  throw
+	    std::runtime_error ( msg.str( ) );
+	}
+      }
+      else
+      {
+	//---------------------------------------------------------------
+	// :TODO: Slower implementation by reading forward in file
+	//---------------------------------------------------------------
+	throw
+	  Unimplemented( "Common::IFrameStreamWrapper::advanceToFrProcData(non-toc)",
+			 streamVersion( ),
+			 __FILE__, __LINE__ );
+      }
+
+      //-----------------------------------------------------------------
+      // Return the information to the caller
+      //-----------------------------------------------------------------
+      return retval;
+    }
+
     template< INT_4U ClassType, typename ChannelType >
     IFrameStream::object_type IFrameStream::
     read_fr_struct( INT_4U Frame, ChannelType Channel, bool Recursively )
@@ -1575,6 +1700,49 @@ namespace FrameCPP
       ERROR_HANDLER( );
     }
 
+    template< INT_4U ClassType, typename ChannelType >
+    IFrameStream::object_type IFrameStream::
+    read_indexed_fr_struct( ChannelType Channel, INT_4U Index, bool Recursively )
+    try
+    {
+      //-----------------------------------------------------------------
+      // Prep for errors
+      //-----------------------------------------------------------------
+      reset( );
+      //-----------------------------------------------------------------
+      // Advance to the requested frame within the stream
+      //-----------------------------------------------------------------
+      object_type	retval;
+
+      m_logNextPtr = false;
+      try
+      {
+	retval = advance_to_indexed_fr_struct< ClassType >( Channel, Index );
+      }
+      catch( ... )
+      {
+	m_logNextPtr = true;
+	throw;
+      }
+      m_logNextPtr = true;
+      if ( Recursively && retval )
+      {
+	//---------------------------------------------------------------
+	// Read until all references are resolved or until FrEndOfFrame
+	//   is reached
+	//---------------------------------------------------------------
+	readRecursive( FrameSpec::Info::FSI_FR_NULL );
+      }
+      //-----------------------------------------------------------------
+      // Return the results
+      //-----------------------------------------------------------------
+      return retval;
+    }
+    catch( ... )
+    {
+      ERROR_HANDLER( );
+    }
+
     //===================================================================
     //===================================================================
     bool OFrameStream::detector_cmp::
