@@ -479,6 +479,7 @@ operator()( IFrameStream& Stream,
     IChecksumOnlyStream	stream( Stream );
 
     crc_file_checksum_only( stream, stream.Header );
+    return;
   }
   //---------------------------------------------------------------------
   // Do initialization
@@ -883,6 +884,7 @@ operator()( IFrameStream& Stream,
 	      }
 	    }
 	    break;
+BEGIN_WIMPLICIT_FALLTHROUGH
 	  case FrameSpec::Info::FSI_FR_ADC_DATA:
 	    if ( m_check_data_valid && qfo )
 	    {
@@ -913,6 +915,7 @@ operator()( IFrameStream& Stream,
 	      }
 	    }
 	    // Fall through so as to check Detector information
+END_WIMPLICIT_FALLTHROUGH
 	  case FrameSpec::Info::FSI_FR_SIM_DATA:
 	  case FrameSpec::Info::FSI_FR_PROC_DATA:
 	    if ( qfo )
@@ -1169,6 +1172,8 @@ ExamineFrHeaderChecksum( chkSum_type Checksum ) const
 void Verify::
 crc_file_checksum_only( IStream& Stream, fr_header_type Header )
 {
+  const std::streampos here( Stream.tellg( ) );
+
   std::unique_ptr< CheckSum > crc( (CheckSum*)NULL );
 
   if ( Stream.GetCheckSumFile( ) )
@@ -1306,6 +1311,8 @@ crc_file_checksum_only( IStream& Stream, fr_header_type Header )
 		     "FR_END_OF_FILE",
 		     m_must_have_eof_checksum );
   }
+  // Rewind stream back to were the checksum was started
+  Stream.seekg( here );
 }
 
 void Verify::
