@@ -521,6 +521,41 @@ namespace FrameCPP
       return cur->second.positionTrigData;
     }
 
+    FrTOC::cmn_position_type FrTOC::
+    positionEvent( const std::string& EventType,
+		   INT_4U Index ) const
+    {
+#if WORKING
+      //-----------------------------------------------------------------
+      // Try to find the channel
+      //-----------------------------------------------------------------
+      MapTrig_type::const_iterator
+	cur = GetTrigData( EventType );
+      if ( cur == FrTOCTrigData::m_info.end( ) )
+      {
+	//---------------------------------------------------------------
+	// EventType does not exist.
+	//---------------------------------------------------------------
+	std::ostringstream	msg;
+
+	msg << "No FrEvent structures with the name " << EventType
+	  ;
+	throw
+	  std::out_of_range( msg.str( ) );
+      }
+      //-----------------------------------------------------------------
+      // Return the offset
+      //-----------------------------------------------------------------
+      return cur->second.positionTrigData;
+#else /* WORKING */
+      // ----------------------------------------------------------------
+      /// \todo Need to fix
+      // ----------------------------------------------------------------
+      throw
+	std::out_of_range( "Not implemented" );
+#endif /* WORKING */
+    }
+
     const FrTOC::cmn_name_container_type& FrTOC::
     nameProc( ) const
     {
@@ -671,6 +706,41 @@ namespace FrameCPP
       return cur->second.positionSimEvent;
     }
 
+    FrTOC::cmn_position_type FrTOC::
+    positionSimEvent( const std::string& EventType,
+		      INT_4U Index ) const
+    {
+#if WORKING
+      //-----------------------------------------------------------------
+      // Try to find the channel
+      //-----------------------------------------------------------------
+      MapTrig_type::const_iterator
+	cur = GetTrigData( EventType );
+      if ( cur == FrTOCTrigData::m_info.end( ) )
+      {
+	//---------------------------------------------------------------
+	// EventType does not exist.
+	//---------------------------------------------------------------
+	std::ostringstream	msg;
+
+	msg << "No FrSimEvent structures with the name " << EventType
+	  ;
+	throw
+	  std::out_of_range( msg.str( ) );
+      }
+      //-----------------------------------------------------------------
+      // Return the offset
+      //-----------------------------------------------------------------
+      return cur->second.positionTrigData;
+#else /* WORKING */
+      // ----------------------------------------------------------------
+      /// \todo Need to fix
+      // ----------------------------------------------------------------
+      throw
+	std::out_of_range( "Not implemented" );
+#endif /* WORKING */
+    }
+
     INT_4U FrTOC::
     nSH( ) const
     {
