@@ -5,6 +5,7 @@
 #include <stdexcept>
 
 #include "ldastoolsal/autoarray.hh"
+#include "ldastoolsal/Memory.hh"
 
 #include "framecpp/Common/Compression.hh"
 #include "framecpp/Common/IOStream.hh"
@@ -1389,7 +1390,7 @@ namespace FrameCPP
     {
       using namespace FrameCPP::Version_3_4_5;
 
-      std::auto_ptr< Vect >	ver5;
+      std::unique_ptr< Vect >	ver5;
       PTR_STRUCT		next;
       
       switch( Stream.GetVersion( ) )
