@@ -1,5 +1,6 @@
 #include <framecpp_config.h>
 
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/mutexlock.hh"
 #include "ldastoolsal/Singleton.hh"
 #include "ldastoolsal/gpstime.hh"
@@ -568,6 +569,9 @@ namespace
   IDTypeToStringMapping::
   IDTypeToStringMapping( )
   {
+    LDASTools::AL::MemChecker::Append( singleton_suicide,
+				       "<anonymous>::IDTypeToStringMapping::singleton_suicide",
+				       5 );
     m_types.push_back( "Unknown/user defined" );
     m_types.push_back( "Time Series" );
     m_types.push_back( "Frequency Series" );
@@ -600,6 +604,9 @@ namespace
   IDSubTypeToStringMappingFrequency::
   IDSubTypeToStringMappingFrequency( )
   {
+    LDASTools::AL::MemChecker::Append( singleton_suicide,
+				       "<anonymous>::IDTypeToStringMappingFrequency::singleton_suicide",
+				       5 );
     m_types.push_back( "Unknown/user defined" );
     m_types.push_back( "Amplitude Spectral Density" );
     m_types.push_back( "Power Spectral Density" );
