@@ -552,6 +552,13 @@ namespace FrameCPP
       return FrTOCEvent::positionEvent( FrameIndex, Event );
     }
 
+    FrTOC::cmn_position_type FrTOC::
+    positionEvent( const std::string& EventType,
+		   INT_4U Index) const
+    {
+      return FrTOCEvent::positionEvent( EventType, Index );
+    }
+
     const FrTOC::cmn_name_container_type& FrTOC::
     nameProc( ) const
     {
@@ -669,6 +676,13 @@ namespace FrameCPP
       return FrTOCSimEvent::positionSimEvent( FrameIndex, SimEvent );
     }
 
+    FrTOC::cmn_position_type FrTOC::
+    positionSimEvent( const std::string& EventType,
+		      INT_4U Index) const
+    {
+      return FrTOCSimEvent::positionSimEvent( EventType, Index );
+    }
+
     INT_4U FrTOC::
     nSH( ) const
     {
