@@ -225,12 +225,12 @@ namespace
     }
 
     waveform_compression( FrameCPP::FrVect::compression_scheme_type Default,
-			  wave_form_type Wave, ... )
+			  int Wave, ... )
     {
       va_list	ap;
       va_start(ap, Wave );
 
-      wave_form_type				wf = Wave;
+      wave_form_type				wf = wave_form_type( Wave );
       FrameCPP::FrVect::compression_scheme_type	cs;
 
       for ( INT_2U x = NO_WAVE_FORM; x < MAX_WAVE_FORM; x++ )
