@@ -689,6 +689,94 @@ test_small_frames( )
   }
 }
 
+void
+test_read_events( )
+{
+  try
+  {
+    static const size_t EVENTS = 2;
+    const std::string event_name( "TesT" );
+
+    //-------------------------------------------------------------------
+    // input buffer needed
+    //-------------------------------------------------------------------
+    std::unique_ptr< frame_buffer_type >
+      i_frame_buf( new frame_buffer_type( std::ios::in ) );
+
+    //-------------------------------------------------------------------
+    // Calculate the filename
+    //-------------------------------------------------------------------
+    std::ostringstream	filename;
+
+    if ( TEST_DIR.size( ) > 0 )
+    {
+      filename << TEST_DIR << "/";
+    }
+    filename << "Z-R_std_test_frame_ver" << FRAME_SPEC_CURRENT
+	     << "-" << 600000000
+	     << "-" << 1
+	     << ".gwf"
+      ;
+
+    //-----------------------------------------------------------------
+    // Open the buffer and the stream
+    //-----------------------------------------------------------------
+    i_frame_buf->open( filename.str( ).c_str( ),
+		       std::ios::in | std::ios::binary );
+
+    IFrameStream	ifs( i_frame_buf.release( ) );
+
+    size_t x = 0;
+    try
+    {
+      while ( true )
+      {
+	ifs.ReadFrEvent( event_name, x );
+	++x;
+      }
+    }
+    catch( const std::range_error& Error )
+    {
+    }
+    catch( const std::exception& Error )
+    {
+    }
+    Test.Check( EVENTS == x )
+      << "Verifying the expected number of events"
+      << std::endl
+      ;
+
+    {
+      static const size_t SIM_EVENTS = size_t( 1 );
+      const std::string sim_event_name( "TesT" );
+      x = 0;
+      try
+      {
+	while ( true )
+        {
+	  ifs.ReadFrSimEvent( sim_event_name, x );
+	  ++x;
+	}
+      }
+      catch( const std::range_error& Error )
+      {
+      }
+      catch( const std::exception& Error )
+      {
+      }
+      Test.Check( SIM_EVENTS == x )
+	<< "Verifying the expected number of simulated events"
+	<< "(expected: " << SIM_EVENTS << " received: " << x << ")"
+	<< std::endl
+	;
+    }
+  }
+  catch( std::exception& Exception )
+  {
+    Test.Check( false ) << "Caught an exception: " << Exception.what( ) << std::endl;
+  }
+}
+
 int
 main( int ArgC, char**ArgV )
 {
@@ -714,6 +802,7 @@ main( int ArgC, char**ArgV )
   test_memory_buffer_ro( );
   test_scanner( );
   test_small_frames( );
+  test_read_events( );
 
   //---------------------------------------------------------------------
   // Testing is complete. Report back to the user
